@@ -48,13 +48,25 @@ class TestAccounts(Case):
     _MODULE = "accounts"
 
 
+class TestBlocks(Case):
+    _MODULE = "blocks"
+
+
 class TestContracts(Case):
     _MODULE = "contracts"
 
 
+class TestProxy(Case):
+    _MODULE = "proxy"
+
+
 class TestStats(Case):
     _MODULE = "stats"
 
 
 class TestTokens(Case):
     _MODULE = "tokens"
+
+
+class TestTransactions(Case):
+    _MODULE = "transactions"
\ No newline at end of file
